import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IAMClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IAMClient";
import { GetAccountPasswordPolicyResponse } from "../models/models_0";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link GetAccountPasswordPolicyCommand}.
 */
export interface GetAccountPasswordPolicyCommandInput {
}
/**
 * @public
 *
 * The output of {@link GetAccountPasswordPolicyCommand}.
 */
export interface GetAccountPasswordPolicyCommandOutput extends GetAccountPasswordPolicyResponse, __MetadataBearer {
}
declare const GetAccountPasswordPolicyCommand_base: {
    new (input: GetAccountPasswordPolicyCommandInput): import("@smithy/smithy-client").CommandImpl<GetAccountPasswordPolicyCommandInput, GetAccountPasswordPolicyCommandOutput, IAMClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * @public
 * <p>Retrieves the password policy for the Amazon Web Services account. This tells you the complexity
 *             requirements and mandatory rotation periods for the IAM user passwords in your account.
 *             For more information about using a password policy, see <a href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_ManagingPasswordPolicies.html">Managing an IAM password
 *                 policy</a>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IAMClient, GetAccountPasswordPolicyCommand } from "@aws-sdk/client-iam"; // ES Modules import
 * // const { IAMClient, GetAccountPasswordPolicyCommand } = require("@aws-sdk/client-iam"); // CommonJS import
 * const client = new IAMClient(config);
 * const input = {};
 * const command = new GetAccountPasswordPolicyCommand(input);
 * const response = await client.send(command);
 * // { // GetAccountPasswordPolicyResponse
 * //   PasswordPolicy: { // PasswordPolicy
 * //     MinimumPasswordLength: Number("int"),
 * //     RequireSymbols: true || false,
 * //     RequireNumbers: true || false,
 * //     RequireUppercaseCharacters: true || false,
 * //     RequireLowercaseCharacters: true || false,
 * //     AllowUsersToChangePassword: true || false,
 * //     ExpirePasswords: true || false,
 * //     MaxPasswordAge: Number("int"),
 * //     PasswordReusePrevention: Number("int"),
 * //     HardExpiry: true || false,
 * //   },
 * // };
 *
 * ```
 *
 * @param GetAccountPasswordPolicyCommandInput - {@link GetAccountPasswordPolicyCommandInput}
 * @returns {@link GetAccountPasswordPolicyCommandOutput}
 * @see {@link GetAccountPasswordPolicyCommandInput} for command's `input` shape.
 * @see {@link GetAccountPasswordPolicyCommandOutput} for command's `response` shape.
 * @see {@link IAMClientResolvedConfig | config} for IAMClient's `config` shape.
 *
 * @throws {@link NoSuchEntityException} (client fault)
 *  <p>The request was rejected because it referenced a resource entity that does not exist. The
 *       error message describes the resource.</p>
 *
 * @throws {@link ServiceFailureException} (server fault)
 *  <p>The request processing has failed because of an unknown error, exception or
 *       failure.</p>
 *
 * @throws {@link IAMServiceException}
 * <p>Base exception class for all service exceptions from IAM service.</p>
 *
 * @example To see the current account password policy
 * ```javascript
 * // The following command displays details about the password policy for the current AWS account.
 * const input = {};
 * const command = new GetAccountPasswordPolicyCommand(input);
 * const response = await client.send(command);
 * /* response ==
 * {
 *   "PasswordPolicy": {
 *     "AllowUsersToChangePassword": false,
 *     "ExpirePasswords": false,
 *     "HardExpiry": false,
 *     "MaxPasswordAge": 90,
 *     "MinimumPasswordLength": 8,
 *     "PasswordReusePrevention": 12,
 *     "RequireLowercaseCharacters": false,
 *     "RequireNumbers": true,
 *     "RequireSymbols": true,
 *     "RequireUppercaseCharacters": false
 *   }
 * }
 * *\/
 * // example id: 5e4598c7-c425-431f-8af1-19073b3c4a5f
 * ```
 *
 */
export declare class GetAccountPasswordPolicyCommand extends GetAccountPasswordPolicyCommand_base {
}
