import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IAMClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IAMClient";
import { ListInstanceProfilesForRoleRequest, ListInstanceProfilesForRoleResponse } from "../models/models_0";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link ListInstanceProfilesForRoleCommand}.
 */
export interface ListInstanceProfilesForRoleCommandInput extends ListInstanceProfilesForRoleRequest {
}
/**
 * @public
 *
 * The output of {@link ListInstanceProfilesForRoleCommand}.
 */
export interface ListInstanceProfilesForRoleCommandOutput extends ListInstanceProfilesForRoleResponse, __MetadataBearer {
}
declare const ListInstanceProfilesForRoleCommand_base: {
    new (input: ListInstanceProfilesForRoleCommandInput): import("@smithy/smithy-client").CommandImpl<ListInstanceProfilesForRoleCommandInput, ListInstanceProfilesForRoleCommandOutput, IAMClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * @public
 * <p>Lists the instance profiles that have the specified associated IAM role. If there
 *             are none, the operation returns an empty list. For more information about instance
 *             profiles, go to <a href="https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_switch-role-ec2_instance-profiles.html">Using
 *                 instance profiles</a> in the <i>IAM User Guide</i>.</p>
 *          <p>You can paginate the results using the <code>MaxItems</code> and <code>Marker</code>
 *             parameters.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IAMClient, ListInstanceProfilesForRoleCommand } from "@aws-sdk/client-iam"; // ES Modules import
 * // const { IAMClient, ListInstanceProfilesForRoleCommand } = require("@aws-sdk/client-iam"); // CommonJS import
 * const client = new IAMClient(config);
 * const input = { // ListInstanceProfilesForRoleRequest
 *   RoleName: "STRING_VALUE", // required
 *   Marker: "STRING_VALUE",
 *   MaxItems: Number("int"),
 * };
 * const command = new ListInstanceProfilesForRoleCommand(input);
 * const response = await client.send(command);
 * // { // ListInstanceProfilesForRoleResponse
 * //   InstanceProfiles: [ // instanceProfileListType // required
 * //     { // InstanceProfile
 * //       Path: "STRING_VALUE", // required
 * //       InstanceProfileName: "STRING_VALUE", // required
 * //       InstanceProfileId: "STRING_VALUE", // required
 * //       Arn: "STRING_VALUE", // required
 * //       CreateDate: new Date("TIMESTAMP"), // required
 * //       Roles: [ // roleListType // required
 * //         { // Role
 * //           Path: "STRING_VALUE", // required
 * //           RoleName: "STRING_VALUE", // required
 * //           RoleId: "STRING_VALUE", // required
 * //           Arn: "STRING_VALUE", // required
 * //           CreateDate: new Date("TIMESTAMP"), // required
 * //           AssumeRolePolicyDocument: "STRING_VALUE",
 * //           Description: "STRING_VALUE",
 * //           MaxSessionDuration: Number("int"),
 * //           PermissionsBoundary: { // AttachedPermissionsBoundary
 * //             PermissionsBoundaryType: "PermissionsBoundaryPolicy",
 * //             PermissionsBoundaryArn: "STRING_VALUE",
 * //           },
 * //           Tags: [ // tagListType
 * //             { // Tag
 * //               Key: "STRING_VALUE", // required
 * //               Value: "STRING_VALUE", // required
 * //             },
 * //           ],
 * //           RoleLastUsed: { // RoleLastUsed
 * //             LastUsedDate: new Date("TIMESTAMP"),
 * //             Region: "STRING_VALUE",
 * //           },
 * //         },
 * //       ],
 * //       Tags: [
 * //         {
 * //           Key: "STRING_VALUE", // required
 * //           Value: "STRING_VALUE", // required
 * //         },
 * //       ],
 * //     },
 * //   ],
 * //   IsTruncated: true || false,
 * //   Marker: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListInstanceProfilesForRoleCommandInput - {@link ListInstanceProfilesForRoleCommandInput}
 * @returns {@link ListInstanceProfilesForRoleCommandOutput}
 * @see {@link ListInstanceProfilesForRoleCommandInput} for command's `input` shape.
 * @see {@link ListInstanceProfilesForRoleCommandOutput} for command's `response` shape.
 * @see {@link IAMClientResolvedConfig | config} for IAMClient's `config` shape.
 *
 * @throws {@link NoSuchEntityException} (client fault)
 *  <p>The request was rejected because it referenced a resource entity that does not exist. The
 *       error message describes the resource.</p>
 *
 * @throws {@link ServiceFailureException} (server fault)
 *  <p>The request processing has failed because of an unknown error, exception or
 *       failure.</p>
 *
 * @throws {@link IAMServiceException}
 * <p>Base exception class for all service exceptions from IAM service.</p>
 *
 */
export declare class ListInstanceProfilesForRoleCommand extends ListInstanceProfilesForRoleCommand_base {
}
