import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IAMClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IAMClient";
import { UntagUserRequest } from "../models/models_1";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link UntagUserCommand}.
 */
export interface UntagUserCommandInput extends UntagUserRequest {
}
/**
 * @public
 *
 * The output of {@link UntagUserCommand}.
 */
export interface UntagUserCommandOutput extends __MetadataBearer {
}
declare const UntagUserCommand_base: {
    new (input: UntagUserCommandInput): import("@smithy/smithy-client").CommandImpl<UntagUserCommandInput, UntagUserCommandOutput, IAMClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * @public
 * <p>Removes the specified tags from the user. For more information about tagging, see <a href="https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html">Tagging IAM resources</a> in the
 *       <i>IAM User Guide</i>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IAMClient, UntagUserCommand } from "@aws-sdk/client-iam"; // ES Modules import
 * // const { IAMClient, UntagUserCommand } = require("@aws-sdk/client-iam"); // CommonJS import
 * const client = new IAMClient(config);
 * const input = { // UntagUserRequest
 *   UserName: "STRING_VALUE", // required
 *   TagKeys: [ // tagKeyListType // required
 *     "STRING_VALUE",
 *   ],
 * };
 * const command = new UntagUserCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param UntagUserCommandInput - {@link UntagUserCommandInput}
 * @returns {@link UntagUserCommandOutput}
 * @see {@link UntagUserCommandInput} for command's `input` shape.
 * @see {@link UntagUserCommandOutput} for command's `response` shape.
 * @see {@link IAMClientResolvedConfig | config} for IAMClient's `config` shape.
 *
 * @throws {@link ConcurrentModificationException} (client fault)
 *  <p>The request was rejected because multiple requests to change this object were submitted
 *       simultaneously. Wait a few minutes and submit your request again.</p>
 *
 * @throws {@link NoSuchEntityException} (client fault)
 *  <p>The request was rejected because it referenced a resource entity that does not exist. The
 *       error message describes the resource.</p>
 *
 * @throws {@link ServiceFailureException} (server fault)
 *  <p>The request processing has failed because of an unknown error, exception or
 *       failure.</p>
 *
 * @throws {@link IAMServiceException}
 * <p>Base exception class for all service exceptions from IAM service.</p>
 *
 * @example To remove a tag from an IAM user
 * ```javascript
 * // The following example shows how to remove tags that are attached to a user named 'anika'.
 * const input = {
 *   "TagKeys": [
 *     "Dept"
 *   ],
 *   "UserName": "anika"
 * };
 * const command = new UntagUserCommand(input);
 * await client.send(command);
 * // example id: to-remove-a-tag-from-an-iam-user-1506719725554
 * ```
 *
 */
export declare class UntagUserCommand extends UntagUserCommand_base {
}
