import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IAMClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IAMClient";
import { UpdateOpenIDConnectProviderThumbprintRequest } from "../models/models_1";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link UpdateOpenIDConnectProviderThumbprintCommand}.
 */
export interface UpdateOpenIDConnectProviderThumbprintCommandInput extends UpdateOpenIDConnectProviderThumbprintRequest {
}
/**
 * @public
 *
 * The output of {@link UpdateOpenIDConnectProviderThumbprintCommand}.
 */
export interface UpdateOpenIDConnectProviderThumbprintCommandOutput extends __MetadataBearer {
}
declare const UpdateOpenIDConnectProviderThumbprintCommand_base: {
    new (input: UpdateOpenIDConnectProviderThumbprintCommandInput): import("@smithy/smithy-client").CommandImpl<UpdateOpenIDConnectProviderThumbprintCommandInput, UpdateOpenIDConnectProviderThumbprintCommandOutput, IAMClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * @public
 * <p>Replaces the existing list of server certificate thumbprints associated with an OpenID
 *             Connect (OIDC) provider resource object with a new list of thumbprints.</p>
 *          <p>The list that you pass with this operation completely replaces the existing list of
 *             thumbprints. (The lists are not merged.)</p>
 *          <p>Typically, you need to update a thumbprint only when the identity provider certificate
 *             changes, which occurs rarely. However, if the provider's certificate
 *                 <i>does</i> change, any attempt to assume an IAM role that specifies
 *             the OIDC provider as a principal fails until the certificate thumbprint is
 *             updated.</p>
 *          <note>
 *             <p>Amazon Web Services secures communication with some OIDC identity providers (IdPs) through our library
 *       of trusted root certificate authorities (CAs) instead of using a certificate thumbprint to
 *       verify your IdP server certificate. In these cases, your legacy thumbprint remains in your
 *       configuration, but is no longer used for validation. These OIDC IdPs include Auth0, GitHub,
 *       GitLab, Google, and those that use an Amazon S3 bucket to host a JSON Web Key Set (JWKS)
 *       endpoint.</p>
 *          </note>
 *          <note>
 *             <p>Trust for the OIDC provider is derived from the provider certificate and is
 *                 validated by the thumbprint. Therefore, it is best to limit access to the
 *                     <code>UpdateOpenIDConnectProviderThumbprint</code> operation to highly
 *                 privileged users.</p>
 *          </note>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IAMClient, UpdateOpenIDConnectProviderThumbprintCommand } from "@aws-sdk/client-iam"; // ES Modules import
 * // const { IAMClient, UpdateOpenIDConnectProviderThumbprintCommand } = require("@aws-sdk/client-iam"); // CommonJS import
 * const client = new IAMClient(config);
 * const input = { // UpdateOpenIDConnectProviderThumbprintRequest
 *   OpenIDConnectProviderArn: "STRING_VALUE", // required
 *   ThumbprintList: [ // thumbprintListType // required
 *     "STRING_VALUE",
 *   ],
 * };
 * const command = new UpdateOpenIDConnectProviderThumbprintCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param UpdateOpenIDConnectProviderThumbprintCommandInput - {@link UpdateOpenIDConnectProviderThumbprintCommandInput}
 * @returns {@link UpdateOpenIDConnectProviderThumbprintCommandOutput}
 * @see {@link UpdateOpenIDConnectProviderThumbprintCommandInput} for command's `input` shape.
 * @see {@link UpdateOpenIDConnectProviderThumbprintCommandOutput} for command's `response` shape.
 * @see {@link IAMClientResolvedConfig | config} for IAMClient's `config` shape.
 *
 * @throws {@link InvalidInputException} (client fault)
 *  <p>The request was rejected because an invalid or out-of-range value was supplied for an
 *       input parameter.</p>
 *
 * @throws {@link NoSuchEntityException} (client fault)
 *  <p>The request was rejected because it referenced a resource entity that does not exist. The
 *       error message describes the resource.</p>
 *
 * @throws {@link ServiceFailureException} (server fault)
 *  <p>The request processing has failed because of an unknown error, exception or
 *       failure.</p>
 *
 * @throws {@link IAMServiceException}
 * <p>Base exception class for all service exceptions from IAM service.</p>
 *
 */
export declare class UpdateOpenIDConnectProviderThumbprintCommand extends UpdateOpenIDConnectProviderThumbprintCommand_base {
}
