import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { IAMServiceException as __BaseException } from "./IAMServiceException";
export declare const AccessAdvisorUsageGranularityType: {
  readonly ACTION_LEVEL: "ACTION_LEVEL";
  readonly SERVICE_LEVEL: "SERVICE_LEVEL";
};
export type AccessAdvisorUsageGranularityType =
  (typeof AccessAdvisorUsageGranularityType)[keyof typeof AccessAdvisorUsageGranularityType];
export interface AccessDetail {
  ServiceName: string | undefined;
  ServiceNamespace: string | undefined;
  Region?: string;
  EntityPath?: string;
  LastAuthenticatedTime?: Date;
  TotalAuthenticatedEntities?: number;
}
export declare const StatusType: {
  readonly Active: "Active";
  readonly Inactive: "Inactive";
};
export type StatusType = (typeof StatusType)[keyof typeof StatusType];
export interface AccessKey {
  UserName: string | undefined;
  AccessKeyId: string | undefined;
  Status: StatusType | undefined;
  SecretAccessKey: string | undefined;
  CreateDate?: Date;
}
export interface AccessKeyLastUsed {
  LastUsedDate: Date | undefined;
  ServiceName: string | undefined;
  Region: string | undefined;
}
export interface AccessKeyMetadata {
  UserName?: string;
  AccessKeyId?: string;
  Status?: StatusType;
  CreateDate?: Date;
}
export interface AddClientIDToOpenIDConnectProviderRequest {
  OpenIDConnectProviderArn: string | undefined;
  ClientID: string | undefined;
}
export declare class InvalidInputException extends __BaseException {
  readonly name: "InvalidInputException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidInputException, __BaseException>
  );
}
export declare class LimitExceededException extends __BaseException {
  readonly name: "LimitExceededException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<LimitExceededException, __BaseException>
  );
}
export declare class NoSuchEntityException extends __BaseException {
  readonly name: "NoSuchEntityException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<NoSuchEntityException, __BaseException>
  );
}
export declare class ServiceFailureException extends __BaseException {
  readonly name: "ServiceFailureException";
  readonly $fault: "server";
  constructor(
    opts: __ExceptionOptionType<ServiceFailureException, __BaseException>
  );
}
export interface AddRoleToInstanceProfileRequest {
  InstanceProfileName: string | undefined;
  RoleName: string | undefined;
}
export declare class EntityAlreadyExistsException extends __BaseException {
  readonly name: "EntityAlreadyExistsException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<EntityAlreadyExistsException, __BaseException>
  );
}
export declare class UnmodifiableEntityException extends __BaseException {
  readonly name: "UnmodifiableEntityException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<UnmodifiableEntityException, __BaseException>
  );
}
export interface AddUserToGroupRequest {
  GroupName: string | undefined;
  UserName: string | undefined;
}
export declare const AssignmentStatusType: {
  readonly Any: "Any";
  readonly Assigned: "Assigned";
  readonly Unassigned: "Unassigned";
};
export type AssignmentStatusType =
  (typeof AssignmentStatusType)[keyof typeof AssignmentStatusType];
export declare const PermissionsBoundaryAttachmentType: {
  readonly Policy: "PermissionsBoundaryPolicy";
};
export type PermissionsBoundaryAttachmentType =
  (typeof PermissionsBoundaryAttachmentType)[keyof typeof PermissionsBoundaryAttachmentType];
export interface AttachedPermissionsBoundary {
  PermissionsBoundaryType?: PermissionsBoundaryAttachmentType;
  PermissionsBoundaryArn?: string;
}
export interface AttachedPolicy {
  PolicyName?: string;
  PolicyArn?: string;
}
export interface AttachGroupPolicyRequest {
  GroupName: string | undefined;
  PolicyArn: string | undefined;
}
export declare class PolicyNotAttachableException extends __BaseException {
  readonly name: "PolicyNotAttachableException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<PolicyNotAttachableException, __BaseException>
  );
}
export interface AttachRolePolicyRequest {
  RoleName: string | undefined;
  PolicyArn: string | undefined;
}
export interface AttachUserPolicyRequest {
  UserName: string | undefined;
  PolicyArn: string | undefined;
}
export interface ChangePasswordRequest {
  OldPassword: string | undefined;
  NewPassword: string | undefined;
}
export declare class EntityTemporarilyUnmodifiableException extends __BaseException {
  readonly name: "EntityTemporarilyUnmodifiableException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      EntityTemporarilyUnmodifiableException,
      __BaseException
    >
  );
}
export declare class InvalidUserTypeException extends __BaseException {
  readonly name: "InvalidUserTypeException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidUserTypeException, __BaseException>
  );
}
export declare class PasswordPolicyViolationException extends __BaseException {
  readonly name: "PasswordPolicyViolationException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      PasswordPolicyViolationException,
      __BaseException
    >
  );
}
export interface CreateAccessKeyRequest {
  UserName?: string;
}
export interface CreateAccessKeyResponse {
  AccessKey: AccessKey | undefined;
}
export declare class ConcurrentModificationException extends __BaseException {
  readonly name: "ConcurrentModificationException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      ConcurrentModificationException,
      __BaseException
    >
  );
}
export interface CreateAccountAliasRequest {
  AccountAlias: string | undefined;
}
export interface CreateGroupRequest {
  Path?: string;
  GroupName: string | undefined;
}
export interface Group {
  Path: string | undefined;
  GroupName: string | undefined;
  GroupId: string | undefined;
  Arn: string | undefined;
  CreateDate: Date | undefined;
}
export interface CreateGroupResponse {
  Group: Group | undefined;
}
export interface Tag {
  Key: string | undefined;
  Value: string | undefined;
}
export interface CreateInstanceProfileRequest {
  InstanceProfileName: string | undefined;
  Path?: string;
  Tags?: Tag[];
}
export interface RoleLastUsed {
  LastUsedDate?: Date;
  Region?: string;
}
export interface Role {
  Path: string | undefined;
  RoleName: string | undefined;
  RoleId: string | undefined;
  Arn: string | undefined;
  CreateDate: Date | undefined;
  AssumeRolePolicyDocument?: string;
  Description?: string;
  MaxSessionDuration?: number;
  PermissionsBoundary?: AttachedPermissionsBoundary;
  Tags?: Tag[];
  RoleLastUsed?: RoleLastUsed;
}
export interface InstanceProfile {
  Path: string | undefined;
  InstanceProfileName: string | undefined;
  InstanceProfileId: string | undefined;
  Arn: string | undefined;
  CreateDate: Date | undefined;
  Roles: Role[] | undefined;
  Tags?: Tag[];
}
export interface CreateInstanceProfileResponse {
  InstanceProfile: InstanceProfile | undefined;
}
export interface CreateLoginProfileRequest {
  UserName: string | undefined;
  Password: string | undefined;
  PasswordResetRequired?: boolean;
}
export interface LoginProfile {
  UserName: string | undefined;
  CreateDate: Date | undefined;
  PasswordResetRequired?: boolean;
}
export interface CreateLoginProfileResponse {
  LoginProfile: LoginProfile | undefined;
}
export interface CreateOpenIDConnectProviderRequest {
  Url: string | undefined;
  ClientIDList?: string[];
  ThumbprintList: string[] | undefined;
  Tags?: Tag[];
}
export interface CreateOpenIDConnectProviderResponse {
  OpenIDConnectProviderArn?: string;
  Tags?: Tag[];
}
export interface CreatePolicyRequest {
  PolicyName: string | undefined;
  Path?: string;
  PolicyDocument: string | undefined;
  Description?: string;
  Tags?: Tag[];
}
export interface Policy {
  PolicyName?: string;
  PolicyId?: string;
  Arn?: string;
  Path?: string;
  DefaultVersionId?: string;
  AttachmentCount?: number;
  PermissionsBoundaryUsageCount?: number;
  IsAttachable?: boolean;
  Description?: string;
  CreateDate?: Date;
  UpdateDate?: Date;
  Tags?: Tag[];
}
export interface CreatePolicyResponse {
  Policy?: Policy;
}
export declare class MalformedPolicyDocumentException extends __BaseException {
  readonly name: "MalformedPolicyDocumentException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      MalformedPolicyDocumentException,
      __BaseException
    >
  );
}
export interface CreatePolicyVersionRequest {
  PolicyArn: string | undefined;
  PolicyDocument: string | undefined;
  SetAsDefault?: boolean;
}
export interface PolicyVersion {
  Document?: string;
  VersionId?: string;
  IsDefaultVersion?: boolean;
  CreateDate?: Date;
}
export interface CreatePolicyVersionResponse {
  PolicyVersion?: PolicyVersion;
}
export interface CreateRoleRequest {
  Path?: string;
  RoleName: string | undefined;
  AssumeRolePolicyDocument: string | undefined;
  Description?: string;
  MaxSessionDuration?: number;
  PermissionsBoundary?: string;
  Tags?: Tag[];
}
export interface CreateRoleResponse {
  Role: Role | undefined;
}
export interface CreateSAMLProviderRequest {
  SAMLMetadataDocument: string | undefined;
  Name: string | undefined;
  Tags?: Tag[];
}
export interface CreateSAMLProviderResponse {
  SAMLProviderArn?: string;
  Tags?: Tag[];
}
export interface CreateServiceLinkedRoleRequest {
  AWSServiceName: string | undefined;
  Description?: string;
  CustomSuffix?: string;
}
export interface CreateServiceLinkedRoleResponse {
  Role?: Role;
}
export interface CreateServiceSpecificCredentialRequest {
  UserName: string | undefined;
  ServiceName: string | undefined;
}
export interface ServiceSpecificCredential {
  CreateDate: Date | undefined;
  ServiceName: string | undefined;
  ServiceUserName: string | undefined;
  ServicePassword: string | undefined;
  ServiceSpecificCredentialId: string | undefined;
  UserName: string | undefined;
  Status: StatusType | undefined;
}
export interface CreateServiceSpecificCredentialResponse {
  ServiceSpecificCredential?: ServiceSpecificCredential;
}
export declare class ServiceNotSupportedException extends __BaseException {
  readonly name: "ServiceNotSupportedException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ServiceNotSupportedException, __BaseException>
  );
}
export interface CreateUserRequest {
  Path?: string;
  UserName: string | undefined;
  PermissionsBoundary?: string;
  Tags?: Tag[];
}
export interface User {
  Path: string | undefined;
  UserName: string | undefined;
  UserId: string | undefined;
  Arn: string | undefined;
  CreateDate: Date | undefined;
  PasswordLastUsed?: Date;
  PermissionsBoundary?: AttachedPermissionsBoundary;
  Tags?: Tag[];
}
export interface CreateUserResponse {
  User?: User;
}
export interface CreateVirtualMFADeviceRequest {
  Path?: string;
  VirtualMFADeviceName: string | undefined;
  Tags?: Tag[];
}
export interface VirtualMFADevice {
  SerialNumber: string | undefined;
  Base32StringSeed?: Uint8Array;
  QRCodePNG?: Uint8Array;
  User?: User;
  EnableDate?: Date;
  Tags?: Tag[];
}
export interface CreateVirtualMFADeviceResponse {
  VirtualMFADevice: VirtualMFADevice | undefined;
}
export interface DeactivateMFADeviceRequest {
  UserName: string | undefined;
  SerialNumber: string | undefined;
}
export interface DeleteAccessKeyRequest {
  UserName?: string;
  AccessKeyId: string | undefined;
}
export interface DeleteAccountAliasRequest {
  AccountAlias: string | undefined;
}
export declare class DeleteConflictException extends __BaseException {
  readonly name: "DeleteConflictException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<DeleteConflictException, __BaseException>
  );
}
export interface DeleteGroupRequest {
  GroupName: string | undefined;
}
export interface DeleteGroupPolicyRequest {
  GroupName: string | undefined;
  PolicyName: string | undefined;
}
export interface DeleteInstanceProfileRequest {
  InstanceProfileName: string | undefined;
}
export interface DeleteLoginProfileRequest {
  UserName: string | undefined;
}
export interface DeleteOpenIDConnectProviderRequest {
  OpenIDConnectProviderArn: string | undefined;
}
export interface DeletePolicyRequest {
  PolicyArn: string | undefined;
}
export interface DeletePolicyVersionRequest {
  PolicyArn: string | undefined;
  VersionId: string | undefined;
}
export interface DeleteRoleRequest {
  RoleName: string | undefined;
}
export interface DeleteRolePermissionsBoundaryRequest {
  RoleName: string | undefined;
}
export interface DeleteRolePolicyRequest {
  RoleName: string | undefined;
  PolicyName: string | undefined;
}
export interface DeleteSAMLProviderRequest {
  SAMLProviderArn: string | undefined;
}
export interface DeleteServerCertificateRequest {
  ServerCertificateName: string | undefined;
}
export interface DeleteServiceLinkedRoleRequest {
  RoleName: string | undefined;
}
export interface DeleteServiceLinkedRoleResponse {
  DeletionTaskId: string | undefined;
}
export interface DeleteServiceSpecificCredentialRequest {
  UserName?: string;
  ServiceSpecificCredentialId: string | undefined;
}
export interface DeleteSigningCertificateRequest {
  UserName?: string;
  CertificateId: string | undefined;
}
export interface DeleteSSHPublicKeyRequest {
  UserName: string | undefined;
  SSHPublicKeyId: string | undefined;
}
export interface DeleteUserRequest {
  UserName: string | undefined;
}
export interface DeleteUserPermissionsBoundaryRequest {
  UserName: string | undefined;
}
export interface DeleteUserPolicyRequest {
  UserName: string | undefined;
  PolicyName: string | undefined;
}
export interface DeleteVirtualMFADeviceRequest {
  SerialNumber: string | undefined;
}
export interface DetachGroupPolicyRequest {
  GroupName: string | undefined;
  PolicyArn: string | undefined;
}
export interface DetachRolePolicyRequest {
  RoleName: string | undefined;
  PolicyArn: string | undefined;
}
export interface DetachUserPolicyRequest {
  UserName: string | undefined;
  PolicyArn: string | undefined;
}
export interface EnableMFADeviceRequest {
  UserName: string | undefined;
  SerialNumber: string | undefined;
  AuthenticationCode1: string | undefined;
  AuthenticationCode2: string | undefined;
}
export declare class InvalidAuthenticationCodeException extends __BaseException {
  readonly name: "InvalidAuthenticationCodeException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      InvalidAuthenticationCodeException,
      __BaseException
    >
  );
}
export declare const ReportStateType: {
  readonly COMPLETE: "COMPLETE";
  readonly INPROGRESS: "INPROGRESS";
  readonly STARTED: "STARTED";
};
export type ReportStateType =
  (typeof ReportStateType)[keyof typeof ReportStateType];
export interface GenerateCredentialReportResponse {
  State?: ReportStateType;
  Description?: string;
}
export interface GenerateOrganizationsAccessReportRequest {
  EntityPath: string | undefined;
  OrganizationsPolicyId?: string;
}
export interface GenerateOrganizationsAccessReportResponse {
  JobId?: string;
}
export declare class ReportGenerationLimitExceededException extends __BaseException {
  readonly name: "ReportGenerationLimitExceededException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      ReportGenerationLimitExceededException,
      __BaseException
    >
  );
}
export interface GenerateServiceLastAccessedDetailsRequest {
  Arn: string | undefined;
  Granularity?: AccessAdvisorUsageGranularityType;
}
export interface GenerateServiceLastAccessedDetailsResponse {
  JobId?: string;
}
export interface GetAccessKeyLastUsedRequest {
  AccessKeyId: string | undefined;
}
export interface GetAccessKeyLastUsedResponse {
  UserName?: string;
  AccessKeyLastUsed?: AccessKeyLastUsed;
}
export declare const EntityType: {
  readonly AWSManagedPolicy: "AWSManagedPolicy";
  readonly Group: "Group";
  readonly LocalManagedPolicy: "LocalManagedPolicy";
  readonly Role: "Role";
  readonly User: "User";
};
export type EntityType = (typeof EntityType)[keyof typeof EntityType];
export interface GetAccountAuthorizationDetailsRequest {
  Filter?: EntityType[];
  MaxItems?: number;
  Marker?: string;
}
export interface PolicyDetail {
  PolicyName?: string;
  PolicyDocument?: string;
}
export interface GroupDetail {
  Path?: string;
  GroupName?: string;
  GroupId?: string;
  Arn?: string;
  CreateDate?: Date;
  GroupPolicyList?: PolicyDetail[];
  AttachedManagedPolicies?: AttachedPolicy[];
}
export interface ManagedPolicyDetail {
  PolicyName?: string;
  PolicyId?: string;
  Arn?: string;
  Path?: string;
  DefaultVersionId?: string;
  AttachmentCount?: number;
  PermissionsBoundaryUsageCount?: number;
  IsAttachable?: boolean;
  Description?: string;
  CreateDate?: Date;
  UpdateDate?: Date;
  PolicyVersionList?: PolicyVersion[];
}
export interface RoleDetail {
  Path?: string;
  RoleName?: string;
  RoleId?: string;
  Arn?: string;
  CreateDate?: Date;
  AssumeRolePolicyDocument?: string;
  InstanceProfileList?: InstanceProfile[];
  RolePolicyList?: PolicyDetail[];
  AttachedManagedPolicies?: AttachedPolicy[];
  PermissionsBoundary?: AttachedPermissionsBoundary;
  Tags?: Tag[];
  RoleLastUsed?: RoleLastUsed;
}
export interface UserDetail {
  Path?: string;
  UserName?: string;
  UserId?: string;
  Arn?: string;
  CreateDate?: Date;
  UserPolicyList?: PolicyDetail[];
  GroupList?: string[];
  AttachedManagedPolicies?: AttachedPolicy[];
  PermissionsBoundary?: AttachedPermissionsBoundary;
  Tags?: Tag[];
}
export interface GetAccountAuthorizationDetailsResponse {
  UserDetailList?: UserDetail[];
  GroupDetailList?: GroupDetail[];
  RoleDetailList?: RoleDetail[];
  Policies?: ManagedPolicyDetail[];
  IsTruncated?: boolean;
  Marker?: string;
}
export interface PasswordPolicy {
  MinimumPasswordLength?: number;
  RequireSymbols?: boolean;
  RequireNumbers?: boolean;
  RequireUppercaseCharacters?: boolean;
  RequireLowercaseCharacters?: boolean;
  AllowUsersToChangePassword?: boolean;
  ExpirePasswords?: boolean;
  MaxPasswordAge?: number;
  PasswordReusePrevention?: number;
  HardExpiry?: boolean;
}
export interface GetAccountPasswordPolicyResponse {
  PasswordPolicy: PasswordPolicy | undefined;
}
export declare const SummaryKeyType: {
  readonly AccessKeysPerUserQuota: "AccessKeysPerUserQuota";
  readonly AccountAccessKeysPresent: "AccountAccessKeysPresent";
  readonly AccountMFAEnabled: "AccountMFAEnabled";
  readonly AccountSigningCertificatesPresent: "AccountSigningCertificatesPresent";
  readonly AttachedPoliciesPerGroupQuota: "AttachedPoliciesPerGroupQuota";
  readonly AttachedPoliciesPerRoleQuota: "AttachedPoliciesPerRoleQuota";
  readonly AttachedPoliciesPerUserQuota: "AttachedPoliciesPerUserQuota";
  readonly GlobalEndpointTokenVersion: "GlobalEndpointTokenVersion";
  readonly GroupPolicySizeQuota: "GroupPolicySizeQuota";
  readonly Groups: "Groups";
  readonly GroupsPerUserQuota: "GroupsPerUserQuota";
  readonly GroupsQuota: "GroupsQuota";
  readonly MFADevices: "MFADevices";
  readonly MFADevicesInUse: "MFADevicesInUse";
  readonly Policies: "Policies";
  readonly PoliciesQuota: "PoliciesQuota";
  readonly PolicySizeQuota: "PolicySizeQuota";
  readonly PolicyVersionsInUse: "PolicyVersionsInUse";
  readonly PolicyVersionsInUseQuota: "PolicyVersionsInUseQuota";
  readonly ServerCertificates: "ServerCertificates";
  readonly ServerCertificatesQuota: "ServerCertificatesQuota";
  readonly SigningCertificatesPerUserQuota: "SigningCertificatesPerUserQuota";
  readonly UserPolicySizeQuota: "UserPolicySizeQuota";
  readonly Users: "Users";
  readonly UsersQuota: "UsersQuota";
  readonly VersionsPerPolicyQuota: "VersionsPerPolicyQuota";
};
export type SummaryKeyType =
  (typeof SummaryKeyType)[keyof typeof SummaryKeyType];
export interface GetAccountSummaryResponse {
  SummaryMap?: Partial<Record<SummaryKeyType, number>>;
}
export interface GetContextKeysForCustomPolicyRequest {
  PolicyInputList: string[] | undefined;
}
export interface GetContextKeysForPolicyResponse {
  ContextKeyNames?: string[];
}
export interface GetContextKeysForPrincipalPolicyRequest {
  PolicySourceArn: string | undefined;
  PolicyInputList?: string[];
}
export declare class CredentialReportExpiredException extends __BaseException {
  readonly name: "CredentialReportExpiredException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      CredentialReportExpiredException,
      __BaseException
    >
  );
}
export declare class CredentialReportNotPresentException extends __BaseException {
  readonly name: "CredentialReportNotPresentException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      CredentialReportNotPresentException,
      __BaseException
    >
  );
}
export declare class CredentialReportNotReadyException extends __BaseException {
  readonly name: "CredentialReportNotReadyException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      CredentialReportNotReadyException,
      __BaseException
    >
  );
}
export declare const ReportFormatType: {
  readonly text_csv: "text/csv";
};
export type ReportFormatType =
  (typeof ReportFormatType)[keyof typeof ReportFormatType];
export interface GetCredentialReportResponse {
  Content?: Uint8Array;
  ReportFormat?: ReportFormatType;
  GeneratedTime?: Date;
}
export interface GetGroupRequest {
  GroupName: string | undefined;
  Marker?: string;
  MaxItems?: number;
}
export interface GetGroupResponse {
  Group: Group | undefined;
  Users: User[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface GetGroupPolicyRequest {
  GroupName: string | undefined;
  PolicyName: string | undefined;
}
export interface GetGroupPolicyResponse {
  GroupName: string | undefined;
  PolicyName: string | undefined;
  PolicyDocument: string | undefined;
}
export interface GetInstanceProfileRequest {
  InstanceProfileName: string | undefined;
}
export interface GetInstanceProfileResponse {
  InstanceProfile: InstanceProfile | undefined;
}
export interface GetLoginProfileRequest {
  UserName: string | undefined;
}
export interface GetLoginProfileResponse {
  LoginProfile: LoginProfile | undefined;
}
export interface GetMFADeviceRequest {
  SerialNumber: string | undefined;
  UserName?: string;
}
export interface GetMFADeviceResponse {
  UserName?: string;
  SerialNumber: string | undefined;
  EnableDate?: Date;
  Certifications?: Record<string, string>;
}
export interface GetOpenIDConnectProviderRequest {
  OpenIDConnectProviderArn: string | undefined;
}
export interface GetOpenIDConnectProviderResponse {
  Url?: string;
  ClientIDList?: string[];
  ThumbprintList?: string[];
  CreateDate?: Date;
  Tags?: Tag[];
}
export declare const SortKeyType: {
  readonly LAST_AUTHENTICATED_TIME_ASCENDING: "LAST_AUTHENTICATED_TIME_ASCENDING";
  readonly LAST_AUTHENTICATED_TIME_DESCENDING: "LAST_AUTHENTICATED_TIME_DESCENDING";
  readonly SERVICE_NAMESPACE_ASCENDING: "SERVICE_NAMESPACE_ASCENDING";
  readonly SERVICE_NAMESPACE_DESCENDING: "SERVICE_NAMESPACE_DESCENDING";
};
export type SortKeyType = (typeof SortKeyType)[keyof typeof SortKeyType];
export interface GetOrganizationsAccessReportRequest {
  JobId: string | undefined;
  MaxItems?: number;
  Marker?: string;
  SortKey?: SortKeyType;
}
export interface ErrorDetails {
  Message: string | undefined;
  Code: string | undefined;
}
export declare const JobStatusType: {
  readonly COMPLETED: "COMPLETED";
  readonly FAILED: "FAILED";
  readonly IN_PROGRESS: "IN_PROGRESS";
};
export type JobStatusType = (typeof JobStatusType)[keyof typeof JobStatusType];
export interface GetOrganizationsAccessReportResponse {
  JobStatus: JobStatusType | undefined;
  JobCreationDate: Date | undefined;
  JobCompletionDate?: Date;
  NumberOfServicesAccessible?: number;
  NumberOfServicesNotAccessed?: number;
  AccessDetails?: AccessDetail[];
  IsTruncated?: boolean;
  Marker?: string;
  ErrorDetails?: ErrorDetails;
}
export interface GetPolicyRequest {
  PolicyArn: string | undefined;
}
export interface GetPolicyResponse {
  Policy?: Policy;
}
export interface GetPolicyVersionRequest {
  PolicyArn: string | undefined;
  VersionId: string | undefined;
}
export interface GetPolicyVersionResponse {
  PolicyVersion?: PolicyVersion;
}
export interface GetRoleRequest {
  RoleName: string | undefined;
}
export interface GetRoleResponse {
  Role: Role | undefined;
}
export interface GetRolePolicyRequest {
  RoleName: string | undefined;
  PolicyName: string | undefined;
}
export interface GetRolePolicyResponse {
  RoleName: string | undefined;
  PolicyName: string | undefined;
  PolicyDocument: string | undefined;
}
export interface GetSAMLProviderRequest {
  SAMLProviderArn: string | undefined;
}
export interface GetSAMLProviderResponse {
  SAMLMetadataDocument?: string;
  CreateDate?: Date;
  ValidUntil?: Date;
  Tags?: Tag[];
}
export interface GetServerCertificateRequest {
  ServerCertificateName: string | undefined;
}
export interface ServerCertificateMetadata {
  Path: string | undefined;
  ServerCertificateName: string | undefined;
  ServerCertificateId: string | undefined;
  Arn: string | undefined;
  UploadDate?: Date;
  Expiration?: Date;
}
export interface ServerCertificate {
  ServerCertificateMetadata: ServerCertificateMetadata | undefined;
  CertificateBody: string | undefined;
  CertificateChain?: string;
  Tags?: Tag[];
}
export interface GetServerCertificateResponse {
  ServerCertificate: ServerCertificate | undefined;
}
export interface GetServiceLastAccessedDetailsRequest {
  JobId: string | undefined;
  MaxItems?: number;
  Marker?: string;
}
export interface TrackedActionLastAccessed {
  ActionName?: string;
  LastAccessedEntity?: string;
  LastAccessedTime?: Date;
  LastAccessedRegion?: string;
}
export interface ServiceLastAccessed {
  ServiceName: string | undefined;
  LastAuthenticated?: Date;
  ServiceNamespace: string | undefined;
  LastAuthenticatedEntity?: string;
  LastAuthenticatedRegion?: string;
  TotalAuthenticatedEntities?: number;
  TrackedActionsLastAccessed?: TrackedActionLastAccessed[];
}
export interface GetServiceLastAccessedDetailsResponse {
  JobStatus: JobStatusType | undefined;
  JobType?: AccessAdvisorUsageGranularityType;
  JobCreationDate: Date | undefined;
  ServicesLastAccessed: ServiceLastAccessed[] | undefined;
  JobCompletionDate: Date | undefined;
  IsTruncated?: boolean;
  Marker?: string;
  Error?: ErrorDetails;
}
export interface GetServiceLastAccessedDetailsWithEntitiesRequest {
  JobId: string | undefined;
  ServiceNamespace: string | undefined;
  MaxItems?: number;
  Marker?: string;
}
export declare const PolicyOwnerEntityType: {
  readonly GROUP: "GROUP";
  readonly ROLE: "ROLE";
  readonly USER: "USER";
};
export type PolicyOwnerEntityType =
  (typeof PolicyOwnerEntityType)[keyof typeof PolicyOwnerEntityType];
export interface EntityInfo {
  Arn: string | undefined;
  Name: string | undefined;
  Type: PolicyOwnerEntityType | undefined;
  Id: string | undefined;
  Path?: string;
}
export interface EntityDetails {
  EntityInfo: EntityInfo | undefined;
  LastAuthenticated?: Date;
}
export interface GetServiceLastAccessedDetailsWithEntitiesResponse {
  JobStatus: JobStatusType | undefined;
  JobCreationDate: Date | undefined;
  JobCompletionDate: Date | undefined;
  EntityDetailsList: EntityDetails[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
  Error?: ErrorDetails;
}
export interface GetServiceLinkedRoleDeletionStatusRequest {
  DeletionTaskId: string | undefined;
}
export interface RoleUsageType {
  Region?: string;
  Resources?: string[];
}
export interface DeletionTaskFailureReasonType {
  Reason?: string;
  RoleUsageList?: RoleUsageType[];
}
export declare const DeletionTaskStatusType: {
  readonly FAILED: "FAILED";
  readonly IN_PROGRESS: "IN_PROGRESS";
  readonly NOT_STARTED: "NOT_STARTED";
  readonly SUCCEEDED: "SUCCEEDED";
};
export type DeletionTaskStatusType =
  (typeof DeletionTaskStatusType)[keyof typeof DeletionTaskStatusType];
export interface GetServiceLinkedRoleDeletionStatusResponse {
  Status: DeletionTaskStatusType | undefined;
  Reason?: DeletionTaskFailureReasonType;
}
export declare const EncodingType: {
  readonly PEM: "PEM";
  readonly SSH: "SSH";
};
export type EncodingType = (typeof EncodingType)[keyof typeof EncodingType];
export interface GetSSHPublicKeyRequest {
  UserName: string | undefined;
  SSHPublicKeyId: string | undefined;
  Encoding: EncodingType | undefined;
}
export interface SSHPublicKey {
  UserName: string | undefined;
  SSHPublicKeyId: string | undefined;
  Fingerprint: string | undefined;
  SSHPublicKeyBody: string | undefined;
  Status: StatusType | undefined;
  UploadDate?: Date;
}
export interface GetSSHPublicKeyResponse {
  SSHPublicKey?: SSHPublicKey;
}
export declare class UnrecognizedPublicKeyEncodingException extends __BaseException {
  readonly name: "UnrecognizedPublicKeyEncodingException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      UnrecognizedPublicKeyEncodingException,
      __BaseException
    >
  );
}
export interface GetUserRequest {
  UserName?: string;
}
export interface GetUserResponse {
  User: User | undefined;
}
export interface GetUserPolicyRequest {
  UserName: string | undefined;
  PolicyName: string | undefined;
}
export interface GetUserPolicyResponse {
  UserName: string | undefined;
  PolicyName: string | undefined;
  PolicyDocument: string | undefined;
}
export interface ListAccessKeysRequest {
  UserName?: string;
  Marker?: string;
  MaxItems?: number;
}
export interface ListAccessKeysResponse {
  AccessKeyMetadata: AccessKeyMetadata[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListAccountAliasesRequest {
  Marker?: string;
  MaxItems?: number;
}
export interface ListAccountAliasesResponse {
  AccountAliases: string[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListAttachedGroupPoliciesRequest {
  GroupName: string | undefined;
  PathPrefix?: string;
  Marker?: string;
  MaxItems?: number;
}
export interface ListAttachedGroupPoliciesResponse {
  AttachedPolicies?: AttachedPolicy[];
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListAttachedRolePoliciesRequest {
  RoleName: string | undefined;
  PathPrefix?: string;
  Marker?: string;
  MaxItems?: number;
}
export interface ListAttachedRolePoliciesResponse {
  AttachedPolicies?: AttachedPolicy[];
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListAttachedUserPoliciesRequest {
  UserName: string | undefined;
  PathPrefix?: string;
  Marker?: string;
  MaxItems?: number;
}
export interface ListAttachedUserPoliciesResponse {
  AttachedPolicies?: AttachedPolicy[];
  IsTruncated?: boolean;
  Marker?: string;
}
export declare const PolicyUsageType: {
  readonly PermissionsBoundary: "PermissionsBoundary";
  readonly PermissionsPolicy: "PermissionsPolicy";
};
export type PolicyUsageType =
  (typeof PolicyUsageType)[keyof typeof PolicyUsageType];
export interface ListEntitiesForPolicyRequest {
  PolicyArn: string | undefined;
  EntityFilter?: EntityType;
  PathPrefix?: string;
  PolicyUsageFilter?: PolicyUsageType;
  Marker?: string;
  MaxItems?: number;
}
export interface PolicyGroup {
  GroupName?: string;
  GroupId?: string;
}
export interface PolicyRole {
  RoleName?: string;
  RoleId?: string;
}
export interface PolicyUser {
  UserName?: string;
  UserId?: string;
}
export interface ListEntitiesForPolicyResponse {
  PolicyGroups?: PolicyGroup[];
  PolicyUsers?: PolicyUser[];
  PolicyRoles?: PolicyRole[];
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListGroupPoliciesRequest {
  GroupName: string | undefined;
  Marker?: string;
  MaxItems?: number;
}
export interface ListGroupPoliciesResponse {
  PolicyNames: string[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListGroupsRequest {
  PathPrefix?: string;
  Marker?: string;
  MaxItems?: number;
}
export interface ListGroupsResponse {
  Groups: Group[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListGroupsForUserRequest {
  UserName: string | undefined;
  Marker?: string;
  MaxItems?: number;
}
export interface ListGroupsForUserResponse {
  Groups: Group[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListInstanceProfilesRequest {
  PathPrefix?: string;
  Marker?: string;
  MaxItems?: number;
}
export interface ListInstanceProfilesResponse {
  InstanceProfiles: InstanceProfile[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListInstanceProfilesForRoleRequest {
  RoleName: string | undefined;
  Marker?: string;
  MaxItems?: number;
}
export interface ListInstanceProfilesForRoleResponse {
  InstanceProfiles: InstanceProfile[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListInstanceProfileTagsRequest {
  InstanceProfileName: string | undefined;
  Marker?: string;
  MaxItems?: number;
}
export interface ListInstanceProfileTagsResponse {
  Tags: Tag[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListMFADevicesRequest {
  UserName?: string;
  Marker?: string;
  MaxItems?: number;
}
export interface MFADevice {
  UserName: string | undefined;
  SerialNumber: string | undefined;
  EnableDate: Date | undefined;
}
export interface ListMFADevicesResponse {
  MFADevices: MFADevice[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListMFADeviceTagsRequest {
  SerialNumber: string | undefined;
  Marker?: string;
  MaxItems?: number;
}
export interface ListMFADeviceTagsResponse {
  Tags: Tag[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListOpenIDConnectProvidersRequest {}
export interface OpenIDConnectProviderListEntry {
  Arn?: string;
}
export interface ListOpenIDConnectProvidersResponse {
  OpenIDConnectProviderList?: OpenIDConnectProviderListEntry[];
}
export interface ListOpenIDConnectProviderTagsRequest {
  OpenIDConnectProviderArn: string | undefined;
  Marker?: string;
  MaxItems?: number;
}
export interface ListOpenIDConnectProviderTagsResponse {
  Tags: Tag[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export declare const PolicyScopeType: {
  readonly AWS: "AWS";
  readonly All: "All";
  readonly Local: "Local";
};
export type PolicyScopeType =
  (typeof PolicyScopeType)[keyof typeof PolicyScopeType];
export interface ListPoliciesRequest {
  Scope?: PolicyScopeType;
  OnlyAttached?: boolean;
  PathPrefix?: string;
  PolicyUsageFilter?: PolicyUsageType;
  Marker?: string;
  MaxItems?: number;
}
export interface ListPoliciesResponse {
  Policies?: Policy[];
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListPoliciesGrantingServiceAccessRequest {
  Marker?: string;
  Arn: string | undefined;
  ServiceNamespaces: string[] | undefined;
}
export declare const PolicyType: {
  readonly INLINE: "INLINE";
  readonly MANAGED: "MANAGED";
};
export type PolicyType = (typeof PolicyType)[keyof typeof PolicyType];
export interface PolicyGrantingServiceAccess {
  PolicyName: string | undefined;
  PolicyType: PolicyType | undefined;
  PolicyArn?: string;
  EntityType?: PolicyOwnerEntityType;
  EntityName?: string;
}
export interface ListPoliciesGrantingServiceAccessEntry {
  ServiceNamespace?: string;
  Policies?: PolicyGrantingServiceAccess[];
}
export interface ListPoliciesGrantingServiceAccessResponse {
  PoliciesGrantingServiceAccess:
    | ListPoliciesGrantingServiceAccessEntry[]
    | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListPolicyTagsRequest {
  PolicyArn: string | undefined;
  Marker?: string;
  MaxItems?: number;
}
export interface ListPolicyTagsResponse {
  Tags: Tag[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListPolicyVersionsRequest {
  PolicyArn: string | undefined;
  Marker?: string;
  MaxItems?: number;
}
export interface ListPolicyVersionsResponse {
  Versions?: PolicyVersion[];
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListRolePoliciesRequest {
  RoleName: string | undefined;
  Marker?: string;
  MaxItems?: number;
}
export interface ListRolePoliciesResponse {
  PolicyNames: string[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListRolesRequest {
  PathPrefix?: string;
  Marker?: string;
  MaxItems?: number;
}
export interface ListRolesResponse {
  Roles: Role[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListRoleTagsRequest {
  RoleName: string | undefined;
  Marker?: string;
  MaxItems?: number;
}
export interface ListRoleTagsResponse {
  Tags: Tag[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListSAMLProvidersRequest {}
export interface SAMLProviderListEntry {
  Arn?: string;
  ValidUntil?: Date;
  CreateDate?: Date;
}
export interface ListSAMLProvidersResponse {
  SAMLProviderList?: SAMLProviderListEntry[];
}
export interface ListSAMLProviderTagsRequest {
  SAMLProviderArn: string | undefined;
  Marker?: string;
  MaxItems?: number;
}
export interface ListSAMLProviderTagsResponse {
  Tags: Tag[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListServerCertificatesRequest {
  PathPrefix?: string;
  Marker?: string;
  MaxItems?: number;
}
export interface ListServerCertificatesResponse {
  ServerCertificateMetadataList: ServerCertificateMetadata[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListServerCertificateTagsRequest {
  ServerCertificateName: string | undefined;
  Marker?: string;
  MaxItems?: number;
}
export interface ListServerCertificateTagsResponse {
  Tags: Tag[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListServiceSpecificCredentialsRequest {
  UserName?: string;
  ServiceName?: string;
}
export interface ServiceSpecificCredentialMetadata {
  UserName: string | undefined;
  Status: StatusType | undefined;
  ServiceUserName: string | undefined;
  CreateDate: Date | undefined;
  ServiceSpecificCredentialId: string | undefined;
  ServiceName: string | undefined;
}
export interface ListServiceSpecificCredentialsResponse {
  ServiceSpecificCredentials?: ServiceSpecificCredentialMetadata[];
}
export interface ListSigningCertificatesRequest {
  UserName?: string;
  Marker?: string;
  MaxItems?: number;
}
export interface SigningCertificate {
  UserName: string | undefined;
  CertificateId: string | undefined;
  CertificateBody: string | undefined;
  Status: StatusType | undefined;
  UploadDate?: Date;
}
export interface ListSigningCertificatesResponse {
  Certificates: SigningCertificate[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListSSHPublicKeysRequest {
  UserName?: string;
  Marker?: string;
  MaxItems?: number;
}
export interface SSHPublicKeyMetadata {
  UserName: string | undefined;
  SSHPublicKeyId: string | undefined;
  Status: StatusType | undefined;
  UploadDate: Date | undefined;
}
export interface ListSSHPublicKeysResponse {
  SSHPublicKeys?: SSHPublicKeyMetadata[];
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListUserPoliciesRequest {
  UserName: string | undefined;
  Marker?: string;
  MaxItems?: number;
}
export interface ListUserPoliciesResponse {
  PolicyNames: string[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListUsersRequest {
  PathPrefix?: string;
  Marker?: string;
  MaxItems?: number;
}
export interface ListUsersResponse {
  Users: User[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListUserTagsRequest {
  UserName: string | undefined;
  Marker?: string;
  MaxItems?: number;
}
export interface ListUserTagsResponse {
  Tags: Tag[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface ListVirtualMFADevicesRequest {
  AssignmentStatus?: AssignmentStatusType;
  Marker?: string;
  MaxItems?: number;
}
export interface ListVirtualMFADevicesResponse {
  VirtualMFADevices: VirtualMFADevice[] | undefined;
  IsTruncated?: boolean;
  Marker?: string;
}
export interface PutGroupPolicyRequest {
  GroupName: string | undefined;
  PolicyName: string | undefined;
  PolicyDocument: string | undefined;
}
export interface PutRolePermissionsBoundaryRequest {
  RoleName: string | undefined;
  PermissionsBoundary: string | undefined;
}
export interface PutRolePolicyRequest {
  RoleName: string | undefined;
  PolicyName: string | undefined;
  PolicyDocument: string | undefined;
}
export interface PutUserPermissionsBoundaryRequest {
  UserName: string | undefined;
  PermissionsBoundary: string | undefined;
}
export interface PutUserPolicyRequest {
  UserName: string | undefined;
  PolicyName: string | undefined;
  PolicyDocument: string | undefined;
}
export interface RemoveClientIDFromOpenIDConnectProviderRequest {
  OpenIDConnectProviderArn: string | undefined;
  ClientID: string | undefined;
}
export interface RemoveRoleFromInstanceProfileRequest {
  InstanceProfileName: string | undefined;
  RoleName: string | undefined;
}
export interface RemoveUserFromGroupRequest {
  GroupName: string | undefined;
  UserName: string | undefined;
}
export interface ResetServiceSpecificCredentialRequest {
  UserName?: string;
  ServiceSpecificCredentialId: string | undefined;
}
export interface ResetServiceSpecificCredentialResponse {
  ServiceSpecificCredential?: ServiceSpecificCredential;
}
export interface ResyncMFADeviceRequest {
  UserName: string | undefined;
  SerialNumber: string | undefined;
  AuthenticationCode1: string | undefined;
  AuthenticationCode2: string | undefined;
}
export interface SetDefaultPolicyVersionRequest {
  PolicyArn: string | undefined;
  VersionId: string | undefined;
}
export declare const GlobalEndpointTokenVersion: {
  readonly v1Token: "v1Token";
  readonly v2Token: "v2Token";
};
export type GlobalEndpointTokenVersion =
  (typeof GlobalEndpointTokenVersion)[keyof typeof GlobalEndpointTokenVersion];
export interface SetSecurityTokenServicePreferencesRequest {
  GlobalEndpointTokenVersion: GlobalEndpointTokenVersion | undefined;
}
export declare class PolicyEvaluationException extends __BaseException {
  readonly name: "PolicyEvaluationException";
  readonly $fault: "server";
  constructor(
    opts: __ExceptionOptionType<PolicyEvaluationException, __BaseException>
  );
}
export declare const ContextKeyTypeEnum: {
  readonly BINARY: "binary";
  readonly BINARY_LIST: "binaryList";
  readonly BOOLEAN: "boolean";
  readonly BOOLEAN_LIST: "booleanList";
  readonly DATE: "date";
  readonly DATE_LIST: "dateList";
  readonly IP: "ip";
  readonly IP_LIST: "ipList";
  readonly NUMERIC: "numeric";
  readonly NUMERIC_LIST: "numericList";
  readonly STRING: "string";
  readonly STRING_LIST: "stringList";
};
export type ContextKeyTypeEnum =
  (typeof ContextKeyTypeEnum)[keyof typeof ContextKeyTypeEnum];
export interface ContextEntry {
  ContextKeyName?: string;
  ContextKeyValues?: string[];
  ContextKeyType?: ContextKeyTypeEnum;
}
export interface SimulateCustomPolicyRequest {
  PolicyInputList: string[] | undefined;
  PermissionsBoundaryPolicyInputList?: string[];
  ActionNames: string[] | undefined;
  ResourceArns?: string[];
  ResourcePolicy?: string;
  ResourceOwner?: string;
  CallerArn?: string;
  ContextEntries?: ContextEntry[];
  ResourceHandlingOption?: string;
  MaxItems?: number;
  Marker?: string;
}
export declare const PolicyEvaluationDecisionType: {
  readonly ALLOWED: "allowed";
  readonly EXPLICIT_DENY: "explicitDeny";
  readonly IMPLICIT_DENY: "implicitDeny";
};
export type PolicyEvaluationDecisionType =
  (typeof PolicyEvaluationDecisionType)[keyof typeof PolicyEvaluationDecisionType];
export interface Position {
  Line?: number;
  Column?: number;
}
export declare const PolicySourceType: {
  readonly AWS_MANAGED: "aws-managed";
  readonly GROUP: "group";
  readonly NONE: "none";
  readonly RESOURCE: "resource";
  readonly ROLE: "role";
  readonly USER: "user";
  readonly USER_MANAGED: "user-managed";
};
export type PolicySourceType =
  (typeof PolicySourceType)[keyof typeof PolicySourceType];
export interface Statement {
  SourcePolicyId?: string;
  SourcePolicyType?: PolicySourceType;
  StartPosition?: Position;
  EndPosition?: Position;
}
export interface OrganizationsDecisionDetail {
  AllowedByOrganizations?: boolean;
}
export interface PermissionsBoundaryDecisionDetail {
  AllowedByPermissionsBoundary?: boolean;
}
export interface ResourceSpecificResult {
  EvalResourceName: string | undefined;
  EvalResourceDecision: PolicyEvaluationDecisionType | undefined;
  MatchedStatements?: Statement[];
  MissingContextValues?: string[];
  EvalDecisionDetails?: Record<string, PolicyEvaluationDecisionType>;
  PermissionsBoundaryDecisionDetail?: PermissionsBoundaryDecisionDetail;
}
export interface EvaluationResult {
  EvalActionName: string | undefined;
  EvalResourceName?: string;
  EvalDecision: PolicyEvaluationDecisionType | undefined;
  MatchedStatements?: Statement[];
  MissingContextValues?: string[];
  OrganizationsDecisionDetail?: OrganizationsDecisionDetail;
  PermissionsBoundaryDecisionDetail?: PermissionsBoundaryDecisionDetail;
  EvalDecisionDetails?: Record<string, PolicyEvaluationDecisionType>;
  ResourceSpecificResults?: ResourceSpecificResult[];
}
export interface SimulatePolicyResponse {
  EvaluationResults?: EvaluationResult[];
  IsTruncated?: boolean;
  Marker?: string;
}
export interface SimulatePrincipalPolicyRequest {
  PolicySourceArn: string | undefined;
  PolicyInputList?: string[];
  PermissionsBoundaryPolicyInputList?: string[];
  ActionNames: string[] | undefined;
  ResourceArns?: string[];
  ResourcePolicy?: string;
  ResourceOwner?: string;
  CallerArn?: string;
  ContextEntries?: ContextEntry[];
  ResourceHandlingOption?: string;
  MaxItems?: number;
  Marker?: string;
}
export interface TagInstanceProfileRequest {
  InstanceProfileName: string | undefined;
  Tags: Tag[] | undefined;
}
export interface TagMFADeviceRequest {
  SerialNumber: string | undefined;
  Tags: Tag[] | undefined;
}
export interface TagOpenIDConnectProviderRequest {
  OpenIDConnectProviderArn: string | undefined;
  Tags: Tag[] | undefined;
}
export interface TagPolicyRequest {
  PolicyArn: string | undefined;
  Tags: Tag[] | undefined;
}
export interface TagRoleRequest {
  RoleName: string | undefined;
  Tags: Tag[] | undefined;
}
export interface TagSAMLProviderRequest {
  SAMLProviderArn: string | undefined;
  Tags: Tag[] | undefined;
}
export interface TagServerCertificateRequest {
  ServerCertificateName: string | undefined;
  Tags: Tag[] | undefined;
}
export interface TagUserRequest {
  UserName: string | undefined;
  Tags: Tag[] | undefined;
}
export interface UntagInstanceProfileRequest {
  InstanceProfileName: string | undefined;
  TagKeys: string[] | undefined;
}
export declare const AccessKeyFilterSensitiveLog: (obj: AccessKey) => any;
export declare const ChangePasswordRequestFilterSensitiveLog: (
  obj: ChangePasswordRequest
) => any;
export declare const CreateAccessKeyResponseFilterSensitiveLog: (
  obj: CreateAccessKeyResponse
) => any;
export declare const CreateLoginProfileRequestFilterSensitiveLog: (
  obj: CreateLoginProfileRequest
) => any;
export declare const ServiceSpecificCredentialFilterSensitiveLog: (
  obj: ServiceSpecificCredential
) => any;
export declare const CreateServiceSpecificCredentialResponseFilterSensitiveLog: (
  obj: CreateServiceSpecificCredentialResponse
) => any;
export declare const VirtualMFADeviceFilterSensitiveLog: (
  obj: VirtualMFADevice
) => any;
export declare const CreateVirtualMFADeviceResponseFilterSensitiveLog: (
  obj: CreateVirtualMFADeviceResponse
) => any;
export declare const ListVirtualMFADevicesResponseFilterSensitiveLog: (
  obj: ListVirtualMFADevicesResponse
) => any;
export declare const ResetServiceSpecificCredentialResponseFilterSensitiveLog: (
  obj: ResetServiceSpecificCredentialResponse
) => any;
